@@ -51,24 +51,21 @@ async function openAboutWelcome() {
   );
   await setAboutWelcomePref(true);
 
-  sandbox
-    .stub(AWScreenUtils, "evaluateScreenTargeting")
-    .resolves(true)
+  sandbox.stub(AWScreenUtils, "evaluateScreenTargeting").callsFake(args => {
+    info(`evaluateScreenTargeting called with args: ${args}`);
     // Renders easy setup import screen as first screen to prevent pin/default dialog boxes breaking tests
-    .withArgs(
-      "doesAppNeedPin && 'browser.shell.checkDefaultBrowser'|preferenceValue && !isDefaultBrowser"
-    )
-    .resolves(false)
-    .withArgs(
-      "!doesAppNeedPin && 'browser.shell.checkDefaultBrowser'|preferenceValue && !isDefaultBrowser"
-    )
-    .resolves(false)
-    .withArgs(
-      "doesAppNeedPin && (!'browser.shell.checkDefaultBrowser'|preferenceValue || isDefaultBrowser)"
-    )
-    .resolves(false)
-    .withArgs("isDeviceMigration")
-    .resolves(false);
+    const falseTargeting = [
+      "isRTAMO",
+      "doesAppNeedPin && (unhandledCampaignAction != 'SET_DEFAULT_BROWSER') && 'browser.shell.checkDefaultBrowser'|preferenceValue && !isDefaultBrowser",
+      "!doesAppNeedPin && (unhandledCampaignAction != 'SET_DEFAULT_BROWSER') && 'browser.shell.checkDefaultBrowser'|preferenceValue && !isDefaultBrowser",
+      "doesAppNeedPin && (!'browser.shell.checkDefaultBrowser'|preferenceValue || isDefaultBrowser || (unhandledCampaignAction == 'SET_DEFAULT_BROWSER'))",
+      "isDeviceMigration",
+    ];
+    if (falseTargeting.includes(args)) {
+      return Promise.resolve(false);
+    }
+    return Promise.resolve(true);
+  });
 
   info("Opening about:welcome");
   let tab = await BrowserTestUtils.openNewForegroundTab(
@@ -77,8 +74,21 @@ async function openAboutWelcome() {
     true
   );
 
-  registerCleanupFunction(async () => {
+  await ContentTask.spawn(tab.linkedBrowser, {}, async () => {
+    await ContentTaskUtils.waitForCondition(
+      () => content.document.querySelector(".AW_EASY_SETUP_ONLY_IMPORT"),
+      `Should render AW_EASY_SETUP_ONLY_IMPORT when opening about:welcome, current screen is: ${
+        content.document.querySelector(".screen")?.classList?.[1]
+      }`
+    );
+  });
+
+  registerCleanupFunction(() => {
     BrowserTestUtils.removeTab(tab);
+    Services.prefs.clearUserPref("browser.aboutwelcome.transitions");
+    Services.prefs.clearUserPref(
+      "intl.multilingual.aboutWelcome.languageMismatchEnabled"
+    );
   });
 
   return {
@@ -135,7 +145,9 @@ async function testScreenContent(
       for (let selector of expected) {
         await ContentTaskUtils.waitForCondition(
           () => selectorIsVisible(selector),
-          `Should render ${selector} in ${experimentName}`
+          `Should render ${selector} in ${experimentName}, current screen is: ${
+            content.document.querySelector(".screen")?.classList?.[1]
+          }`
         );
       }
       for (let selector of unexpected) {
@@ -224,7 +236,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_accept() {
   // Ignore the telemetry of the initial welcome screen.
   flushClickTelemetry();
 
-  resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
+  await resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
 
   await testScreenContent(
     browser,
@@ -343,8 +355,8 @@ add_task(async function test_aboutwelcome_languageSwitcher_decline() {
   // Ignore the telemetry of the initial welcome screen.
   flushClickTelemetry();
 
-  resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
-  resolveInstaller();
+  await resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
+  await resolveInstaller();
 
   await testScreenContent(
     browser,
@@ -411,7 +423,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_asyncCalls() {
   );
   ok(mockable.installLangPack.notCalled);
 
-  resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
+  await resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
 
   await TestUtils.waitForCondition(
     () => mockable.installLangPack.called,
@@ -419,7 +431,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_asyncCalls() {
   );
   ok(mockable.getAvailableLangpacks.called);
 
-  resolveInstaller();
+  await resolveInstaller();
 });
 
 /**
@@ -443,7 +455,7 @@ add_task(async function test_aboutwelcome_fallback_locale() {
   );
   ok(mockable.installLangPack.notCalled);
 
-  resolveLangPacks(["en-US"]);
+  await resolveLangPacks(["en-US"]);
 
   await TestUtils.waitForCondition(
     () => mockable.installLangPack.called,
@@ -451,7 +463,7 @@ add_task(async function test_aboutwelcome_fallback_locale() {
   );
   ok(mockable.getAvailableLangpacks.called);
 
-  resolveInstaller();
+  await resolveInstaller();
 });
 
 /**
@@ -470,7 +482,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_noMatch() {
   await clickVisibleButton(browser, `button.primary[value="primary_button"]`);
 
   // Klingon is not supported.
-  resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
+  await resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
 
   await testScreenContent(
     browser,
@@ -516,6 +528,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_bidiNotSupported() {
   );
 
   sinon.assert.notCalled(mockable.setRequestedAppLocales);
+  Services.prefs.clearUserPref("intl.multilingual.liveReloadBidirectional");
 });
 
 /**
@@ -530,7 +543,7 @@ add_task(
       systemLocale: "ar-EG", // Arabic (Egypt)
       appLocale: "en-US",
     });
-    resolveLangPacks([]);
+    await resolveLangPacks([]);
 
     const { browser } = await openAboutWelcome();
 
@@ -550,6 +563,7 @@ add_task(
     );
 
     sinon.assert.notCalled(mockable.setRequestedAppLocales);
+    Services.prefs.clearUserPref("intl.multilingual.liveReloadBidirectional");
   }
 );
 
@@ -570,7 +584,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_bidiNotSupported() {
   info("Clicking the primary button to start installing the langpack.");
   await clickVisibleButton(browser, `button.primary[value="primary_button"]`);
 
-  resolveLangPacks(["ar-EG", "es-ES", "fr-FR"]);
+  await resolveLangPacks(["ar-EG", "es-ES", "fr-FR"]);
 
   await testScreenContent(
     browser,
@@ -582,6 +596,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_bidiNotSupported() {
   );
 
   sinon.assert.notCalled(mockable.setRequestedAppLocales);
+  Services.prefs.clearUserPref("intl.multilingual.liveReloadBidirectional");
 });
 
 /**
@@ -599,7 +614,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_cancelWaiting() {
 
   info("Clicking the primary button to start the onboarding process.");
   await clickVisibleButton(browser, `button.primary[value="primary_button"]`);
-  resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
+  await resolveLangPacks(["es-MX", "es-ES", "fr-FR"]);
 
   await testScreenContent(
     browser,
@@ -676,7 +691,7 @@ add_task(async function test_aboutwelcome_languageSwitcher_MR() {
   info("Clicking the primary button to view language switching screen.");
   await clickVisibleButton(browser, `button.primary[value="primary_button"]`);
 
-  resolveLangPacks(["es-AR"]);
+  await resolveLangPacks(["es-AR"]);
   await testScreenContent(
     browser,
     "Live language switching, asking for a language",
