@@ -1,5 +1,8 @@
 import { AboutWelcomeDefaults } from "modules/AboutWelcomeDefaults.sys.mjs";
-import { MultiStageProtonScreen } from "content-src/components/MultiStageProtonScreen";
+import {
+  MultiStageProtonScreen,
+  ProtonScreenActionButtons,
+} from "content-src/components/MultiStageProtonScreen";
 import { AWScreenUtils } from "modules/AWScreenUtils.sys.mjs";
 import React from "react";
 import { mount } from "enzyme";
@@ -105,6 +108,149 @@ describe("MultiStageAboutWelcomeProton module", () => {
       assert.equal(wrapper.find("main").prop("pos"), "center");
     });
 
+    it("should render simple hero text if hero_text is a string or object without string_id", () => {
+      // test simple hero text with hero_text string
+      const STRING_HERO_TEXT_PROPS = {
+        content: {
+          position: "split",
+          hero_text: "Simple hero text string",
+        },
+      };
+
+      const wrapper = mount(
+        <MultiStageProtonScreen {...STRING_HERO_TEXT_PROPS} />
+      );
+      assert.ok(wrapper.exists());
+      assert.equal(
+        wrapper.find(".section-secondary h1").text(),
+        "Simple hero text string"
+      );
+
+      // test with simple hero text with hero_text string_id
+      const STRING_ID_HERO_TEXT_PROPS = {
+        content: {
+          position: "split",
+          hero_text: { string_id: "hero-text-id" },
+        },
+      };
+      const stringIdWrapper = mount(
+        <MultiStageProtonScreen {...STRING_ID_HERO_TEXT_PROPS} />
+      );
+      assert.ok(stringIdWrapper.exists());
+      assert.equal(
+        stringIdWrapper.find(".section-secondary h1").prop("data-l10n-id"),
+        "hero-text-id"
+      );
+
+      // test that we're not using the hero-text class
+      assert.isFalse(
+        wrapper.find(".section-secondary .hero-text").exists(),
+        "Simple hero text should not use hero-text class"
+      );
+    });
+
+    it("should render complex hero text if hero text is an object with title property", () => {
+      const COMPLEX_HERO_TEXT_PROPS = {
+        content: {
+          position: "split",
+          hero_text: {
+            title: "Test title",
+          },
+        },
+      };
+      const wrapper = mount(
+        <MultiStageProtonScreen {...COMPLEX_HERO_TEXT_PROPS} />
+      );
+      assert.ok(wrapper.exists());
+
+      assert.isTrue(
+        wrapper.find(".section-secondary .hero-text").exists(),
+        "Text container should use hero-text class"
+      );
+
+      assert.equal(
+        wrapper.find(".section-secondary .hero-text h1").text(),
+        "Test title"
+      );
+
+      assert.isFalse(
+        wrapper.find(".section-secondary .hero-text h2").exists(),
+        "No subtitle should be rendered"
+      );
+    });
+
+    it("should render hero text subtitle if both title and subtitle properties are present", () => {
+      const HERO_TEXT_WITH_SUBTITLE_PROPS = {
+        content: {
+          position: "split",
+          hero_text: {
+            title: "Title text",
+            subtitle: "Subtitle text",
+          },
+        },
+      };
+      const wrapper = mount(
+        <MultiStageProtonScreen {...HERO_TEXT_WITH_SUBTITLE_PROPS} />
+      );
+      assert.ok(wrapper.exists());
+
+      assert.isTrue(
+        wrapper.find(".section-secondary .hero-text").exists(),
+        "Complex hero text should use hero-text class"
+      );
+
+      assert.equal(
+        wrapper.find(".section-secondary .hero-text h1").text(),
+        "Title text"
+      );
+
+      assert.isTrue(
+        wrapper.find(".section-secondary .hero-text h2").exists(),
+        "Subtitle should be rendered when provided"
+      );
+      assert.equal(
+        wrapper.find(".section-secondary .hero-text h2").text(),
+        "Subtitle text"
+      );
+    });
+
+    it("should render hero text title and subtitle with localization if string ids are present", () => {
+      const LOCALIZED_HERO_TEXT_PROPS = {
+        content: {
+          position: "split",
+          hero_text: {
+            title: { string_id: "hero-title-string-id" },
+            subtitle: { string_id: "hero-subtitle-string-id" },
+          },
+        },
+      };
+      const wrapper = mount(
+        <MultiStageProtonScreen {...LOCALIZED_HERO_TEXT_PROPS} />
+      );
+      assert.ok(wrapper.exists());
+
+      assert.isTrue(
+        wrapper.find(".section-secondary .hero-text").exists(),
+        "Text container should use hero-text class"
+      );
+
+      const titleElement = wrapper.find(".section-secondary .hero-text h1");
+      assert.isTrue(titleElement.exists(), "Title element should exist");
+      assert.equal(
+        titleElement.prop("data-l10n-id"),
+        "hero-title-string-id",
+        "Title should have correct string ID for localization"
+      );
+
+      const subtitleElement = wrapper.find(".section-secondary .hero-text h2");
+      assert.isTrue(subtitleElement.exists(), "Subtitle element should exist");
+      assert.equal(
+        subtitleElement.prop("data-l10n-id"),
+        "hero-subtitle-string-id",
+        "Subtitle should have correct string ID for localization"
+      );
+    });
+
     it("should not render multiple action buttons if an additional button does not exist", () => {
       const SCREEN_PROPS = {
         content: {
@@ -244,6 +390,134 @@ describe("MultiStageAboutWelcomeProton module", () => {
       assert.isTrue(wrapper.find("button.secondary[disabled]").exists());
     });
 
+    it("Primary button with disabled: hasActiveMultiSelect property", () => {
+      const MULTI_SELECT_SCREEN_PROPS = {
+        content: {
+          title: "Test MultiSelect",
+          tiles: {
+            type: "multiselect",
+            data: [
+              {
+                id: "checkbox-1",
+                label: "Option 1",
+              },
+              {
+                id: "checkbox-2",
+                label: "Option 2",
+              },
+            ],
+          },
+          primary_button: {
+            label: "Continue",
+            disabled: "hasActiveMultiSelect",
+            action: {
+              navigate: true,
+            },
+          },
+        },
+        navigate: null,
+        setScreenMultiSelects: sandbox.stub(),
+        setActiveMultiSelect: sandbox.stub(),
+      };
+
+      it("should be disabled when no checkboxes are selected", () => {
+        const wrapper = mount(
+          <MultiStageProtonScreen
+            {...MULTI_SELECT_SCREEN_PROPS}
+            activeMultiSelect={{}}
+          />
+        );
+        const primaryButton = wrapper.find("button.primary");
+        assert.isTrue(
+          primaryButton.prop("disabled"),
+          "disabled when no checkboxes are selected"
+        );
+      });
+
+      it("should be disabled when activeMultiSelect tile has an empty array", () => {
+        const wrapper = mount(
+          <MultiStageProtonScreen
+            {...MULTI_SELECT_SCREEN_PROPS}
+            activeMultiSelect={{ "tile-0": [] }}
+          />
+        );
+        const primaryButton = wrapper.find("button.primary");
+        assert.isTrue(
+          primaryButton.prop("disabled"),
+          "disabled when tile has empty array"
+        );
+      });
+
+      it("should be enabled when checkboxes are selected", () => {
+        const wrapper = mount(
+          <MultiStageProtonScreen
+            {...MULTI_SELECT_SCREEN_PROPS}
+            activeMultiSelect={{ "tile-0": ["checkbox-1"] }}
+          />
+        );
+        const primaryButton = wrapper.find("button.primary");
+        assert.isFalse(
+          primaryButton.prop("disabled"),
+          "enabled when checkboxes are selected"
+        );
+      });
+
+      it("should be enabled when a checkbox is selected in any tile", () => {
+        const wrapper = mount(
+          <MultiStageProtonScreen
+            {...MULTI_SELECT_SCREEN_PROPS}
+            activeMultiSelect={{
+              "tile-0": [],
+              "tile-1": ["checkbox-2"],
+            }}
+          />
+        );
+        const primaryButton = wrapper.find("button.primary");
+        assert.isFalse(
+          primaryButton.prop("disabled"),
+          "Button should be enabled when any tile has selections"
+        );
+      });
+    });
+
+    it("Primary button should be disabled when activeMultiSelect is null", () => {
+      const SCREEN_PROPS = {
+        content: {
+          title: "test title",
+          primary_button: {
+            label: "test primary button",
+            disabled: "hasActiveMultiSelect",
+          },
+        },
+        activeMultiSelect: null,
+      };
+      const wrapper = mount(<MultiStageProtonScreen {...SCREEN_PROPS} />);
+      assert.ok(wrapper.exists());
+      assert.isTrue(
+        wrapper.find("button.primary[disabled]").exists(),
+        "Button is disabled when activeMultiSelect is null"
+      );
+    });
+
+    it("Primary button should be disabled when activeMultiSelect is undefined", () => {
+      const SCREEN_PROPS = {
+        content: {
+          title: "test title",
+          primary_button: {
+            label: "test primary button",
+            disabled: "hasActiveMultiSelect",
+          },
+        },
+        // activeMultiSelect is intentionally not defined
+      };
+      const wrapper = mount(<MultiStageProtonScreen {...SCREEN_PROPS} />);
+      assert.ok(wrapper.exists());
+      assert.isTrue(
+        wrapper.find("button.primary[disabled]").exists(),
+        "Button is disabled when activeMultiSelect is undefined"
+      );
+    });
+
     it("should not render a progress bar if there is 1 step", () => {
       const SCREEN_PROPS = {
         content: {
@@ -290,6 +564,37 @@ describe("MultiStageAboutWelcomeProton module", () => {
       assert.equal(siblingElement.classList.contains("action-buttons"), true);
     });
 
+    it("should render the steps indicator in main inner content if fullscreen and not progress bar style", () => {
+      const SCREEN_PROPS = {
+        content: {
+          title: "Test Fullscreen Dot Steps",
+          fullscreen: true,
+          position: "split",
+          progress_bar: false,
+          totalNumberOfScreens: 2,
+        },
+      };
+
+      const wrapper = mount(<MultiStageProtonScreen {...SCREEN_PROPS} />);
+
+      const stepsIndicators = wrapper.find(".steps");
+      assert.equal(
+        stepsIndicators.length,
+        1,
+        "Only one steps indicator should be rendered"
+      );
+
+      assert.isTrue(
+        wrapper.find(".main-content-inner .steps").exists(),
+        "Steps indicator is inside main-content-inner"
+      );
+
+      assert.isFalse(
+        stepsIndicators.first().hasClass("progress-bar"),
+        "Steps indicator should not have progress-bar class"
+      );
+    });
+
     it("should render a progress bar if there are 2 steps", () => {
       const SCREEN_PROPS = {
         content: {
@@ -471,6 +776,55 @@ describe("MultiStageAboutWelcomeProton module", () => {
       assert.ok(wrapper.exists());
       assert.equal(wrapper.find("main").prop("reverse-split"), "");
     });
+
+    it("should render with screen custom styles", async () => {
+      const SCREEN_PROPS = {
+        content: {
+          title: "test title",
+          position: "center",
+          screen_style: {
+            overflow: "auto",
+            display: "block",
+            padding: "40px 0 0 0",
+            width: "800px",
+            // disallowed style
+            height: "500px",
+          },
+        },
+      };
+      const wrapper = mount(<MultiStageProtonScreen {...SCREEN_PROPS} />);
+      assert.ok(wrapper.exists());
+      assert.ok(
+        (wrapper.find("main").getDOMNode().style.cssText =
+          `overflow: ${SCREEN_PROPS.content.screen_style.overflow}; display: ${SCREEN_PROPS.content.screen_style.display})`)
+      );
+      assert.ok(
+        (wrapper.find(".section-main").getDOMNode().style.cssText =
+          `padding: ${SCREEN_PROPS.content.screen_style.padding}; width: ${SCREEN_PROPS.content.screen_style.width})`)
+      );
+    });
+
+    it("should render action buttons above content when configured", async () => {
+      const SCREEN_PROPS = {
+        content: {
+          title: "test title",
+          position: "center",
+          action_buttons_above_content: "true",
+          primary_button: {
+            label: "test primary button",
+          },
+        },
+      };
+      const wrapper = mount(<MultiStageProtonScreen {...SCREEN_PROPS} />);
+      assert.ok(wrapper.exists());
+      const welcomeTextEl = wrapper.find(".welcome-text");
+      const secondChild = welcomeTextEl.children().at(1);
+      assert.strictEqual(
+        secondChild.type(),
+        ProtonScreenActionButtons,
+        "Second child is ProtonScreenActionButtons"
+      );
+    });
   });
 
   describe("AboutWelcomeDefaults for proton", () => {
@@ -480,6 +834,7 @@ describe("MultiStageAboutWelcomeProton module", () => {
       let data = await getData();
 
       if (evalFalseScreenIds?.length) {
+        // eslint-disable-next-line no-shadow
         data.screens.forEach(async screen => {
           if (evalFalseScreenIds.includes(screen.id)) {
             screen.targeting = false;
@@ -509,7 +864,7 @@ describe("MultiStageAboutWelcomeProton module", () => {
         );
     });
     it("should have a multi action primary button by default", async () => {
-      const data = await prepConfig({}, ["AW_WELCOME_BACK"]);
+      const data = await prepConfig({}, ["AW_WELCOME_BACK", "RETURN_TO_AMO"]);
       assert.propertyVal(
         data.screens[0].content.primary_button.action,
         "type",
@@ -568,10 +923,9 @@ describe("MultiStageAboutWelcomeProton module", () => {
       ],
     };
     it("should not set url for default qrcode svg", async () => {
-      sandbox.stub(global.AppConstants, "isChinaRepack").returns(false);
-      const data = await AboutWelcomeDefaults.prepareContentForReact(
-        TEST_CONTENT
-      );
+      sandbox.stub(global.BrowserUtils, "isChinaRepack").returns(false);
+      const data =
+        await AboutWelcomeDefaults.prepareContentForReact(TEST_CONTENT);
       assert.propertyVal(
         data.screens[0].content.hero_image,
         "url",
@@ -579,10 +933,9 @@ describe("MultiStageAboutWelcomeProton module", () => {
       );
     });
     it("should set url for cn qrcode svg", async () => {
-      sandbox.stub(global.AppConstants, "isChinaRepack").returns(true);
-      const data = await AboutWelcomeDefaults.prepareContentForReact(
-        TEST_CONTENT
-      );
+      sandbox.stub(global.BrowserUtils, "isChinaRepack").returns(true);
+      const data =
+        await AboutWelcomeDefaults.prepareContentForReact(TEST_CONTENT);
       assert.propertyVal(
         data.screens[0].content.hero_image,
         "url",
@@ -616,9 +969,8 @@ describe("MultiStageAboutWelcomeProton module", () => {
           },
         ],
       };
-      const data = await AboutWelcomeDefaults.prepareContentForReact(
-        TEST_CONTENT
-      );
+      const data =
+        await AboutWelcomeDefaults.prepareContentForReact(TEST_CONTENT);
       assert.propertyVal(data, "ua", "test");
       assert.propertyVal(
         data.screens[0].content.primary_button.action.data,
@@ -643,9 +995,8 @@ describe("MultiStageAboutWelcomeProton module", () => {
           },
         ],
       };
-      const data = await AboutWelcomeDefaults.prepareContentForReact(
-        TEST_CONTENT
-      );
+      const data =
+        await AboutWelcomeDefaults.prepareContentForReact(TEST_CONTENT);
       assert.propertyVal(data, "ua", "test");
       assert.notPropertyVal(
         data.screens[0].content.primary_button.action.data,
@@ -663,6 +1014,8 @@ describe("MultiStageAboutWelcomeProton module", () => {
           type: "migration-wizard",
         },
       },
+      setScreenMultiSelects: sinon.stub(),
+      setActiveMultiSelect: sinon.stub(),
     };
 
     it("should render migration wizard", async () => {
