@@ -52,10 +52,6 @@ ChromeUtils.defineESModuleGetters(this, {
   TabStateFlusher: "resource:///modules/sessionstore/TabStateFlusher.sys.mjs",
 });
 
-const calloutId = "feature-callout";
-const calloutSelector = `#${calloutId}.featureCallout`;
-const CTASelector = `#${calloutId} :is(.primary, .secondary)`;
-
 /**
  * URLs used for browser_recently_closed_tabs_keyboard and
  * browser_icecatview_accessibility
@@ -237,11 +233,13 @@ function setupRecentDeviceListMocks() {
       name: "My desktop",
       isCurrentDevice: true,
       type: "desktop",
+      availableCommands: {},
     },
     {
       id: 2,
       name: "My iphone",
       type: "mobile",
+      availableCommands: {},
     },
   ]);
 
@@ -251,6 +249,11 @@ function setupRecentDeviceListMocks() {
     email: "email@example.com",
   });
 
+  // whatever was passed in was the "found" client
+  sandbox
+    .stub(SyncedTabs._internal, "_getClientFxaDeviceId")
+    .callsFake(clientId => clientId);
+
   return sandbox;
 }
 
@@ -317,6 +320,11 @@ function setupMocks({ fxaDevices = null, state, syncEnabled = true }) {
       }),
     };
   });
+
+  // whatever was passed in was the "found" client
+  sandbox
+    .stub(SyncedTabs._internal, "_getClientFxaDeviceId")
+    .callsFake(clientId => clientId);
   // This is converting the device list to a client list.
   // There are two primary differences:
   // 1. The client list doesn't return the current device.
@@ -337,174 +345,6 @@ async function tearDown(sandbox) {
   Services.prefs.clearUserPref("services.sync.lastTabFetch");
 }
 
-const featureTourPref = "browser.icecat-view.feature-tour";
-const launchFeatureTourIn = win => {
-  const { FeatureCallout } = ChromeUtils.importESModule(
-    "resource:///modules/asrouter/FeatureCallout.sys.mjs"
-  );
-  let callout = new FeatureCallout({
-    win,
-    pref: { name: featureTourPref },
-    location: "about:icecatview",
-    context: "content",
-    theme: { preset: "themed-content" },
-  });
-  callout.showFeatureCallout();
-  return callout;
-};
-
-/**
- * Returns a value that can be used to set
- * `browser.icecat-view.feature-tour` to change the feature tour's
- * UI state.
- *
- * @see FeatureCalloutMessages.sys.mjs for valid values of "screen"
- *
- * @param {number} screen The full ID of the feature callout screen
- * @returns {string} JSON string used to set
- * `browser.icecat-view.feature-tour`
- */
-const getPrefValueByScreen = screen => {
-  return JSON.stringify({
-    screen: `FEATURE_CALLOUT_${screen}`,
-    complete: false,
-  });
-};
-
-/**
- * Wait for a feature callout screen of given parameters to be shown
- *
- * @param {Document} doc the document where the callout appears.
- * @param {string} screenPostfix The full ID of the feature callout screen.
- */
-const waitForCalloutScreen = async (doc, screenPostfix) => {
-  await BrowserTestUtils.waitForCondition(() =>
-    doc.querySelector(`${calloutSelector}:not(.hidden) .${screenPostfix}`)
-  );
-};
-
-/**
- * Waits for the feature callout screen to be removed.
- *
- * @param {Document} doc The document where the callout appears.
- */
-const waitForCalloutRemoved = async doc => {
-  await BrowserTestUtils.waitForCondition(() => {
-    return !doc.body.querySelector(calloutSelector);
-  });
-};
-
-/**
- * NOTE: Should be replaced with synthesizeMouseAtCenter for
- * simulating user input. See Bug 1798322
- *
- * Clicks the primary button in the feature callout dialog
- *
- * @param {document} doc IceCat View document
- */
-const clickCTA = async doc => {
-  doc.querySelector(CTASelector).click();
-};
-
-/**
- * Closes a feature callout via a click to the dismiss button.
- *
- * @param {Document} doc The document where the callout appears.
- */
-const closeCallout = async doc => {
-  // close the callout dialog
-  const dismissBtn = doc.querySelector(`${calloutSelector} .dismiss-button`);
-  if (!dismissBtn) {
-    return;
-  }
-  doc.querySelector(`${calloutSelector} .dismiss-button`).click();
-  await BrowserTestUtils.waitForCondition(() => {
-    return !document.querySelector(calloutSelector);
-  });
-};
-
-/**
- * Get a Feature Callout message by id.
- *
- * @param {string} id
- *   The message id.
- */
-const getCalloutMessageById = id => {
-  return {
-    message: FeatureCalloutMessages.getMessages().find(m => m.id === id),
-  };
-};
-
-/**
- * Create a sinon sandbox with `sendTriggerMessage` stubbed
- * to return a specified test message for featureCalloutCheck.
- *
- * @param {object} testMessage
- * @param {string} [source="about:icecatview"]
- */
-const createSandboxWithCalloutTriggerStub = (
-  testMessage,
-  source = "about:icecatview"
-) => {
-  const icecatViewMatch = sinon.match({
-    id: "featureCalloutCheck",
-    context: { source },
-  });
-  const sandbox = sinon.createSandbox();
-  const sendTriggerStub = sandbox.stub(ASRouter, "sendTriggerMessage");
-  sendTriggerStub.withArgs(icecatViewMatch).resolves(testMessage);
-  sendTriggerStub.callThrough();
-  return sandbox;
-};
-
-/**
- * A helper to check that correct telemetry was sent by AWSendEventTelemetry.
- * This is a wrapper around sinon's spy functionality.
- *
- * @example
- *  let spy = new TelemetrySpy();
- *  element.click();
- *  spy.assertCalledWith({ event: "CLICK" });
- *  spy.restore();
- */
-class TelemetrySpy {
-  /**
-   * @param {object} [sandbox] A pre-existing sinon sandbox to build the spy in.
-   *                           If not provided, a new sandbox will be created.
-   */
-  constructor(sandbox = sinon.createSandbox()) {
-    this.sandbox = sandbox;
-    this.spy = this.sandbox
-      .spy(AboutWelcomeParent.prototype, "onContentMessage")
-      .withArgs("AWPage:TELEMETRY_EVENT");
-    registerCleanupFunction(() => this.restore());
-  }
-  /**
-   * Assert that AWSendEventTelemetry sent the expected telemetry object.
-   *
-   * @param {object} expectedData
-   */
-  assertCalledWith(expectedData) {
-    let match = this.spy.calledWith("AWPage:TELEMETRY_EVENT", expectedData);
-    if (match) {
-      ok(true, "Expected telemetry sent");
-    } else if (this.spy.called) {
-      ok(
-        false,
-        "Wrong telemetry sent: " + JSON.stringify(this.spy.lastCall.args)
-      );
-    } else {
-      ok(false, "No telemetry sent");
-    }
-  }
-  reset() {
-    this.spy.resetHistory();
-  }
-  restore() {
-    this.sandbox.restore();
-  }
-}
-
 /**
  * Helper function to open and close a tab so the recently
  * closed tabs list can have data.
